@@ -1,12 +1,13 @@
 from .function import Function
-from .job import JobDef, JobInfo, JobsWithPagination
+from .job import CachedJobInfo, JobDef, JobInfo, JobsWithPagination
 from .queue import Queue, QueueStats
 
 __all__ = [
-    "JobInfo",
-    "JobDef",
-    "JobsWithPagination",
-    "QueueStats",
+    "CachedJobInfo",
     "Function",
+    "JobDef",
+    "JobInfo",
+    "JobsWithPagination",
     "Queue",
+    "QueueStats",
 ]
